# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/55_nbks.ipynb.

# %% auto 0
__all__ = ['NB', 'NBS', 'CELL', 'CODE', 'LINE', 'CELLS', 'SHELL', 'SOURCE', 'NOTEBOOK', 'NOTEBOOKS', 'CELL_TYPE', 'HTML', 'LEXER',
           'MODULE', 'IPYTHON', 'FORMATTER', 'GET_IPYTHON']

# %% ../nbs/55_nbks.ipynb 4
from .args import TYPE

# %% ../nbs/55_nbks.ipynb 5
NB = 'nb'
NBS = f'{NB}s'
CELL = 'cell'

CODE = 'code'
LINE = 'line'

CELLS = f'{CELL}s'
SHELL = 'shell'

SOURCE = 'source'

NOTEBOOK = 'notebook'
NOTEBOOKS = f'{NOTEBOOK}s'

CELL_TYPE = f'{CELL}_{TYPE}'

# %% ../nbs/55_nbks.ipynb 6
HTML = 'html'
LEXER = 'lexer'
MODULE = 'module'
IPYTHON = 'ipython'
FORMATTER = 'formatter'
GET_IPYTHON = f'get_{IPYTHON}'
