# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/92_byte.ipynb.

# %% auto 0
__all__ = ['B', 'BYTE', 'BYTES', 'KILOBYTE', 'MEGABYTE', 'GIGABYTE', 'TERABYTE', 'PETABYTE', 'EXABYTE', 'ZETTABYTE', 'YOTTABYTE',
           'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB', 'BYTE_UNITS', 'BYTE_SYMBS']

# %% ../nbs/92_byte.ipynb 4
from nlit.unit import (
    k, M, G, T, P, E, Z, Y,
    KILO, MEGA, GIGA, TERA, PETA, EXA, ZETTA, YOTTA,
)

# %% ../nbs/92_byte.ipynb 6
B     = 'B'
BYTE  = 'byte'
BYTES = f'{BYTE}s'

# %% ../nbs/92_byte.ipynb 8
KILOBYTE  = f'{KILO}{BYTE}'
MEGABYTE  = f'{MEGA}{BYTE}'
GIGABYTE  = f'{GIGA}{BYTE}'
TERABYTE  = f'{TERA}{BYTE}'
PETABYTE  = f'{PETA}{BYTE}'
EXABYTE   = f'{EXA}{BYTE}'
ZETTABYTE = f'{ZETTA}{BYTE}'
YOTTABYTE = f'{YOTTA}{BYTE}'

# %% ../nbs/92_byte.ipynb 10
KB = f'{k}{B}'
MB = f'{M}{B}'
GB = f'{G}{B}'
TB = f'{T}{B}'
PB = f'{P}{B}'
EB = f'{E}{B}'
ZB = f'{Z}{B}'
YB = f'{Y}{B}'

# %% ../nbs/92_byte.ipynb 13
BYTE_UNITS = (BYTE, KILOBYTE, MEGABYTE, GIGABYTE, TERABYTE, PETABYTE, EXABYTE, ZETTABYTE, YOTTABYTE, )

# %% ../nbs/92_byte.ipynb 15
BYTE_SYMBS = (B, KB, MB, GB, TB, PB, EB, ZB, YB, )
