# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/60_narr.ipynb.

# %% auto 0
__all__ = ['NDIM', 'DIMS', 'DTYPE', 'SHAPE', 'ARRAY', 'TOARRAY', 'TODENSE', 'TOLIST', 'MIN', 'MAX', 'SUM', 'STD', 'VAR', 'NORM',
           'MEAN', 'MEDIAN', 'CENTROID']

# %% ../nbs/60_narr.ipynb 5
NDIM = 'ndim'
DIMS = 'dims'

DTYPE = 'dtype'
SHAPE = 'shape'

ARRAY = 'array'

TOARRAY = 'toarray'
TODENSE = 'todense'
TOLIST = 'tolist'

# %% ../nbs/60_narr.ipynb 6
MIN = 'min'
MAX = 'max'
SUM = 'sum'
STD = 'std'
VAR = 'var'
NORM = 'norm'
MEAN = 'mean'
MEDIAN = 'median'
CENTROID = 'centroid'
