# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/54_docs.ipynb.

# %% auto 0
__all__ = ['NOTES', 'WARNS', 'RAISES', 'YIELDS', 'METHODS', 'RETURNS', 'EXAMPLES', 'RECEIVES', 'SEE_ALSO', 'ATTRIBUTES',
           'REFERENCES', 'PARAMETERS']

# %% ../nbs/54_docs.ipynb 4
NOTES = 'notes'
WARNS = 'warns'

RAISES = 'raises'
YIELDS = 'yields'

METHODS = 'methods'
RETURNS = 'returns'

EXAMPLES = 'examples'
RECEIVES = 'receives'
SEE_ALSO = 'see_also'

ATTRIBUTES = 'attributes'
REFERENCES = 'references'
PARAMETERS = 'parameters'
