# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/62_pddf.ipynb.

# %% auto 0
__all__ = ['DF', 'DS', 'DX', 'DATA', 'ASTYPE', 'DATASET', 'DATAFRAME', 'IDX', 'INDEX', 'CAT', 'CATS', 'NCAT', 'CATEGORY',
           'CATEGORIES', 'CODE', 'CODES', 'COL', 'COLS', 'NCOL', 'COLUMNS', 'ROW', 'ROWS', 'NROW', 'GET', 'SHAPE',
           'LOC', 'CLOC', 'ILOC', 'ICAT', 'UNNAMED', 'UNNAMED_CLN']

# %% ../nbs/62_pddf.ipynb 5
from nchr import CLN

# %% ../nbs/62_pddf.ipynb 6
DF = 'df'
DS = 'ds'
DX = 'dx'
DATA = 'data'

ASTYPE = 'astype'
DATASET = f'{DATA}set'
DATAFRAME = f'{DATA}frame'

# %% ../nbs/62_pddf.ipynb 7
IDX = 'idx'
INDEX = 'index'

# %% ../nbs/62_pddf.ipynb 8
CAT = 'cat'
CATS = f'{CAT}s'
NCAT = f'n{CAT}'

CATEGORY = f'{CAT}egory'
CATEGORIES = f'{CAT}egories'

# %% ../nbs/62_pddf.ipynb 9
CODE = 'code'
CODES = f'{CODE}s'

# %% ../nbs/62_pddf.ipynb 10
COL = 'col'
COLS = f'{COL}s'
NCOL = f'n{COL}'
COLUMNS = f'{COL}umns'

# %% ../nbs/62_pddf.ipynb 11
ROW = 'row'
ROWS = f'{ROW}s'
NROW = f'n{ROW}'

# %% ../nbs/62_pddf.ipynb 12
GET = 'get'
SHAPE = f'shape'

# %% ../nbs/62_pddf.ipynb 13
LOC = 'loc'
CLOC = f'c{LOC}'
ILOC = f'i{LOC}'
ICAT = f'i{CAT}'

# %% ../nbs/62_pddf.ipynb 14
UNNAMED = 'unnamed'

UNNAMED_CLN = f'{UNNAMED}{CLN}'
