# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/30_exps.ipynb.

# %% auto 0
__all__ = ['ID', 'IDX', 'ITEM', 'NAME', 'SEED', 'BATCH', 'LABEL', 'TOTAL', 'METHOD', 'PCT', 'PERCENT', 'DAY', 'TIME', 'TIMEPOINT',
           'TIMEPOINTS', 'CNT', 'COUNT', 'NORM', 'NORMALIZED', 'CON', 'COND', 'CONDITION', 'CONDITIONS', 'REP', 'REPL',
           'REPLICATE', 'SMP', 'SMPL', 'SAMP', 'SAMPLE', 'SAMPLES', 'SAMPLE_IDX', 'TREATMENT', 'TREATMENTS', 'SENS',
           'SENSITIVITY', 'SENSITIVITIES', 'CAT', 'CATS', 'CATEGORY', 'CATEGORIES', 'FEAT', 'FEATURE', 'FEATURES',
           'FEATURE_TYPE', 'CLST', 'LEIDEN', 'CLUSTER', 'LOUVAIN', 'CLUSTERS', 'MAX_CLUSTERS', 'CLIP', 'SUB', 'SSET',
           'SUBSET', 'REPLACE', 'SD', 'SD1', 'SD2', 'SD3', 'SAMPLE_NAME', 'CONDITION_REPLICATE', 'CONDITION_TIMEPOINT',
           'COND_REPL', 'COND_TIME', 'CR', 'CT', 'CRT', 'OP', 'DATA', 'DIFF', 'DEG', 'DEGREE', 'KERN', 'KERNEL',
           'DEGREES', 'DIFF_OP', 'POT', 'POTENTIAL', 'DIFF_POT', 'DIFF_POTENTIAL', 'AFF', 'AFFINITY', 'KERNEL_DEGREE']

# %% ../nbs/30_exps.ipynb 4
from nchr import S_, U1

# %% ../nbs/30_exps.ipynb 6
ID = 'id'
IDX = 'idx'

# %% ../nbs/30_exps.ipynb 7
ITEM = 'item'
NAME = 'name'
SEED = 'seed'

# %% ../nbs/30_exps.ipynb 8
BATCH = 'batch'
LABEL = 'label'
TOTAL = 'total'

# %% ../nbs/30_exps.ipynb 9
METHOD = 'method'

# %% ../nbs/30_exps.ipynb 10
PCT = 'pct'
PERCENT = 'percent'

# %% ../nbs/30_exps.ipynb 11
DAY = 'day'
TIME = 'time'
TIMEPOINT = f'{TIME}point'
TIMEPOINTS = f'{TIMEPOINT}s'

# %% ../nbs/30_exps.ipynb 12
CNT = 'cnt'
COUNT = 'count'

# %% ../nbs/30_exps.ipynb 13
NORM = 'norm'
NORMALIZED = f'{NORM}alized'

# %% ../nbs/30_exps.ipynb 14
CON = 'con'
COND = f'{CON}d'
CONDITION = f'{COND}ition'
CONDITIONS = f'{CONDITION}s'

# %% ../nbs/30_exps.ipynb 15
REP = 'rep'
REPL = f'{REP}l'
REPLICATE = f'{REPL}icate'

# %% ../nbs/30_exps.ipynb 16
SMP = 'smp'
SMPL = f'{SMP}l'

SAMP = 'samp'
SAMPLE = f'{SAMP}le'
SAMPLES = f'{SAMPLE}s'

SAMPLE_IDX = f'{SAMPLE}{U1}{IDX}'

# %% ../nbs/30_exps.ipynb 17
TREATMENT = f'treatment'
TREATMENTS = f'{TREATMENT}s'

# %% ../nbs/30_exps.ipynb 18
SENS = 'sens'
SENSITIVITY = f'{SENS}itivity'
SENSITIVITIES = f'{SENS}itivities'

# %% ../nbs/30_exps.ipynb 19
CAT = 'cat'
CATS = f'{CAT}s'
CATEGORY = f'{CAT}egory'
CATEGORIES = f'{CAT}egories'

# %% ../nbs/30_exps.ipynb 20
FEAT = 'feat'
FEATURE = f'{FEAT}ure'
FEATURES = f'{FEATURE}s'
FEATURE_TYPE = f'{FEATURE}_type'

# %% ../nbs/30_exps.ipynb 21
CLST = 'clst'
LEIDEN = 'leiden'
CLUSTER = 'cluster'
LOUVAIN = 'louvain'

CLUSTERS = f'{CLUSTER}s'

# %% ../nbs/30_exps.ipynb 22
MAX_CLUSTERS = f'max_{CLUSTERS}'

# %% ../nbs/30_exps.ipynb 23
CLIP = 'clip'

# %% ../nbs/30_exps.ipynb 24
SUB = 'sub'
SSET = 'sset'
SUBSET = 'subset'
REPLACE = 'replace'

# %% ../nbs/30_exps.ipynb 25
SD = 'sd'
SD1 = f'{SD}1'
SD2 = f'{SD}2'
SD3 = f'{SD}3'

# %% ../nbs/30_exps.ipynb 26
SAMPLE_NAME = f'{SAMPLE}{U1}{NAME}'

CONDITION_REPLICATE = f'{CONDITION}{U1}{REPLICATE}'
CONDITION_TIMEPOINT = f'{CONDITION}{U1}{TIMEPOINT}'

COND_REPL = f'{COND}{U1}{REPL}'
COND_TIME = f'{COND}{U1}{TIME}'

# %% ../nbs/30_exps.ipynb 27
CR = 'ct'
CT = 'cr'
CRT = 'crt'

# %% ../nbs/30_exps.ipynb 28
OP = 'op'
DATA = 'data'
DIFF = 'diff'

DEG = 'deg'
DEGREE = f'{DEG}ree'

KERN = 'kern'
KERNEL = f'{KERN}el'

DEGREES = f'{DEGREE}s'
DIFF_OP = f'{DIFF}_{OP}'

POT = 'pot'
POTENTIAL = f'{POT}ential'
DIFF_POT = f'{DIFF}_{POT}'
DIFF_POTENTIAL = f'{DIFF}_{POTENTIAL}'


AFF = 'aff'
AFFINITY = f'{AFF}inity'

KERNEL_DEGREE = f'{KERNEL}_{DEGREE}'
