# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/51_exts.ipynb.

# %% auto 0
__all__ = ['GZ', 'H5', 'PT', 'PY', 'BED', 'CSV', 'MTX', 'TAR', 'TSV', 'NPY', 'NPZ', 'TXT', 'PIP', 'PTH', 'YML', 'ZIP', 'JSON',
           'H5AD', 'IPYNB', 'ARROW', 'FASTA', 'PARQUET', 'AVI', 'GIF', 'EXT_GZ', 'EXT_H5', 'EXT_PT', 'EXT_PY',
           'EXT_BED', 'EXT_CSV', 'EXT_MTX', 'EXT_TAR', 'EXT_TSV', 'EXT_NPY', 'EXT_NPZ', 'EXT_TXT', 'EXT_PIP', 'EXT_PTH',
           'EXT_YML', 'EXT_ZIP', 'EXT_JSON', 'EXT_H5AD', 'EXT_IPYNB', 'EXT_ARROW', 'EXT_FASTA', 'EXT_PARQUET',
           'EXT_TAR_GZ', 'EXT_AVI', 'EXT_GIF']

# %% ../nbs/51_exts.ipynb 4
from nchr import PERIOD

# %% ../nbs/51_exts.ipynb 6
GZ = f'gz'
H5 = f'h5'
PT = f'pt'
PY = f'py'

BED = f'bed'
CSV = f'csv'
MTX = f'mtx'
TAR = f'tar'
TSV = f'tsv'
NPY = f'npy'
NPZ = f'npz'
TXT = f'txt'
PIP = f'pip'
PTH = f'pth'
YML = f'yml'
ZIP = f'zip'

JSON = f'json'
H5AD = f'h5ad'
IPYNB = f'ipynb'

ARROW = 'arrow'
FASTA = 'fasta'
PARQUET = 'parquet'


AVI = 'avi'
GIF = f'gif'


# %% ../nbs/51_exts.ipynb 8
EXT_GZ = f'{PERIOD}{GZ}'
EXT_H5 = f'{PERIOD}{H5}'
EXT_PT = f'{PERIOD}{PT}'
EXT_PY = f'{PERIOD}{PY}'

EXT_BED = f'{PERIOD}{BED}'
EXT_CSV = f'{PERIOD}{CSV}'
EXT_MTX = f'{PERIOD}{MTX}'
EXT_TAR = f'{PERIOD}{TAR}'
EXT_TSV = f'{PERIOD}{TSV}'
EXT_NPY = f'{PERIOD}{NPY}'
EXT_NPZ = f'{PERIOD}{NPZ}'
EXT_TXT = f'{PERIOD}{TXT}'
EXT_PIP = f'{PERIOD}{PIP}'
EXT_PTH = f'{PERIOD}{PTH}'
EXT_YML = f'{PERIOD}{YML}'
EXT_ZIP = f'{PERIOD}{ZIP}'

EXT_JSON = f'{PERIOD}{JSON}'
EXT_H5AD = f'{PERIOD}{H5AD}'
EXT_IPYNB = f'{PERIOD}{IPYNB}'

EXT_ARROW = f'{PERIOD}{ARROW}'
EXT_FASTA = f'{PERIOD}{FASTA}'

EXT_PARQUET = f'{PERIOD}{PARQUET}'

EXT_TAR_GZ = f'{EXT_TAR}{EXT_GZ}'

EXT_AVI = f'{PERIOD}{AVI}'
EXT_GIF = f'{PERIOD}{GIF}'
