# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/05_vals.ipynb.

# %% auto 0
__all__ = ['OBJ', 'KWS', 'CLS', 'NEW', 'INI', 'ANN', 'SUP', 'DEF', 'INS', 'OBJVAL', 'KWSVAL', 'CLSVAL', 'NEWVAL', 'INIVAL',
           'ANNVAL', 'SUPVAL', 'DEFVAL']

# %% ../nbs/05_vals.ipynb 5
OBJ = 'obj' # instance
KWS = 'kws' # kwargs
CLS = 'cls' # class
NEW = 'new' # new
INI = 'ini' # init
ANN = 'ann' # annotation
SUP = 'sup' # super
DEF = 'sef' # default


INS = 'ins' # instance

# %% ../nbs/05_vals.ipynb 6
OBJVAL = f'{OBJ}val'
KWSVAL = f'{KWS}val'
CLSVAL = f'{CLS}val'
NEWVAL = f'{NEW}val'
INIVAL = f'{INI}val'
ANNVAL = f'{ANN}val'
SUPVAL = f'{SUP}val'
DEFVAL = f'{DEF}val'
